@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20230731';
+our $VERSION = '0.20230831';
 
-# Table last modified: 2023-07-31
+# Table last modified: 2023-08-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -63,7 +63,7 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|76|2[015]|9[5-7]|0[35-7])|406))',
+    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|2[015]|9[5-7]|7[46]|0[35-7])|406))',
     '061' => '(?:(?:1(?:39[2-6]|49[236-8]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
@@ -104,18 +104,18 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|0[2367]|4[15]|1[01]|3[1-358]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
-    '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[578]|3[01367]|7[026]|4[235-8]|2[146-9]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:6[26]|8[38]|0[178]|5[013-589]|4[367]|3[3568]|1[0138]|2[3-69]|7[258])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
+    '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[578]|3[01367]|7[026]|4[235-8]|2[146-9]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:6[26]|8[38]|5[013-589]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[024578]|5[016])|2(?:5[0-2569]|3\d|6[01356]|7[036-8]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|5(?:1[028]|8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|4[35-8]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-57-9])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|444)|6[09]50))',
-    '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
+    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-57-9])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
+    '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|1[0-246-9]|4[08]|6[038])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])|797))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|8[0-3568])|3(?:2[25689]|1[0356]|7[2359]|8[013-689]|3[34]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|0[1467]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|3[0-5])|5(?:[78][0356]|4[018]|2[458]|6[2369]|1[1246]|3[0138]|0[1-35689]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
+    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|0[14679]|3[0-5])|5(?:[78][0356]|4[018]|2[458]|6[2369]|1[1246]|3[0138]|0[1-35689]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|0[1-468]|8[16]|1[0-2]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|2[0-468]|7[147]|4[01356]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
@@ -202,7 +202,7 @@ our %ZIP_TABLE = (
     '214' => '(?:85(?:[26]5|8[058]|7[01]))',
     '215' => '(?:85(?:09|30|42|66|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
-    '220' => '(?:8(?:5(?:77|1[015]|6[05-7]|3[0689]|2[0-3]|5[89]|8[0568]|0[12]|4[0-2])|6(?:53|78|0[149]|1[1-6]|6[08]|8[046]|2[035])|7(?:11|39|65|2[02]|5[05])|080|173|401))',
+    '220' => '(?:8(?:5(?:77|1[015]|6[05-7]|3[0689]|2[0-3]|5[89]|8[0568]|4[0-2]|0[127-9])|6(?:53|78|0[149]|1[1-6]|6[08]|8[046]|2[035])|7(?:11|39|65|2[02]|5[05])|080|173|401))',
     '221' => '(?:8(?:5(?:[46]0|37|88|2[0239]|5[08]|1[017])|7(?:41|65|1[28]|0[1-35])|6(?:[68]6|11|23)))',
     '222' => '(?:8(?:5(?:3[03]|8[056]|6[1-6]|7[57]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:85(?:7[027]|[58][058]|1[0-25]|2[0-35-7]|6[067]|4[0-2]|0[125-8]|3[039]))',
@@ -240,7 +240,7 @@ our %ZIP_TABLE = (
     '258' => '(?:(?:85(?:11|77|85|3[38]|0[16])|0195))',
     '259' => '(?:(?:0(?:1(?:9[2-467]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|[23]92)))',
     '260' => '(?:8(?:6(?:0[13467]|1[0-389]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|0[1-35-9]|3[4-68]|6[0-467]|2[13478]|1[0-3568])|7(?:1[02357]|0[137]|3[34]|2[02])))',
-    '261' => '(?:8(?:5(?:1[0-35]|3[0359]|6[068]|7[57]|5[0248]|0[1-478]|8[125-8]|4[145]|2[0-28])|6(?:09|86)|733))',
+    '261' => '(?:8(?:5(?:1[0-35]|6[0168]|3[0359]|7[57]|5[0248]|0[1-478]|8[125-8]|4[145]|2[0-28])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:0[26]|1[0-24])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|66|77|8[58]|5[05]|0[56])|733))',
     '264' => '(?:8(?:5(?:[135]0|8[25]|0[15])|6(?:04|46)|733))',
@@ -259,7 +259,7 @@ our %ZIP_TABLE = (
     '282' => '(?:86(?:02|10))',
     '283' => '(?:(?:8(?:5(?:11|55|88|0[15])|6(?:50|86)|701)|0195))',
     '284' => '(?:8555)',
-    '285' => '(?:8(?:5(?:33|50|67|8[0568]|2[0-2]|1[01]|0[1-359])|6(?:19|55|68)|765))',
+    '285' => '(?:8(?:5(?:33|50|67|8[0568]|2[0-2]|1[01]|0[1-359])|6(?:19|55|68)|7(?:41|65)))',
     '286' => '(?:(?:8(?:5(?:01|2[013]|8[58])|686)|0292))',
     '287' => '(?:(?:8(?:5(?:[58]5|10|0[1-3])|601)|0292))',
     '288' => '(?:8601)',
@@ -571,7 +571,7 @@ our %ZIP_TABLE = (
     '602' => '(?:8(?:5(?:[27]0|01|55|66|8[058]|1[01])|6(?:02|11)))',
     '603' => '(?:85(?:11|22|55|77|88))',
     '604' => '(?:8(?:5(?:20|1[015]|0[1258]|8[058]|7[178]|6[07]|5[01568])|666))',
-    '605' => '(?:8(?:5(?:11|0[15])|686))',
+    '605' => '(?:8(?:5[01]1|686))',
     '606' => '(?:85(?:11|22|36|40|[58][58]|0[1257]))',
     '607' => '(?:85[017]1)',
     '610' => '(?:(?:0(?:3(?:80|9[3-7])|19[256]|28[179])|119[2578]))',
@@ -680,7 +680,7 @@ our %ZIP_TABLE = (
     '717' => '(?:8501)',
     '718' => '(?:(?:85(?:[135]0|01|85)|0392))',
     '719' => '(?:(?:0(?:39[238]|19[25]|295)|3(?:19[2-57]|292)|119[235-8]))',
-    '720' => '(?:(?:8(?:5(?:55|1[0-2578]|3[156]|0[1-47-9]|2[024-7])|6(?:01|50|4[0135]|3[6-9]))|039[278]|219[25]))',
+    '720' => '(?:(?:8(?:5(?:55|1[0-2578]|3[156]|0[1-47-9]|2[024-7])|6(?:01|50|3[6-9]|4[01357]))|039[278]|219[25]))',
     '721' => '(?:8(?:5(?:7[5-7]|6[47]|2[28]|8[568]|4[0135]|1[0145]|5[01568]|0[125])|6(?:31|88|0[17])))',
     '722' => '(?:(?:8(?:5(?:10|0[1-35-8])|60[1245])|2(?:19[238]|49[2-4]|39[23])|1(?:19[23]|[47]92)|039[23]))',
     '723' => '(?:8(?:5(?:01|20|55|1[0-25])|6(?:01|86|1[01])))',
@@ -770,7 +770,7 @@ our %ZIP_TABLE = (
     '809' => '(?:8501)',
     '810' => '(?:8(?:5(?:3[0-357-9]|1[1-9]|5[135-8]|7[01578]|2[0-578]|0[1-46-9]|8[13-57-9]|4[013-6]|6[0135-8])|6(?:8[035689]|3[134679]|4[28]|6[02-79]|7[03-7]|1[0179]|0[13-9]|2[0-2579]|5[0-6])|7(?:98|2[0-257]|3[14]|0[157]|1[06-8])))',
     '811' => '(?:(?:2(?:29[2-578]|19[2-6]|39[2358]|49[2568]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|0(?:19[2-7]|295)|1(?:39[2-6]|292)|5192))',
-    '812' => '(?:(?:8(?:6(?:8[0134679]|3\d|0[1-9]|7[025-8]|5[0-79]|[14][0-8]|2[0-24-9]|6[0-25689])|5(?:[1-3578]\d|0[1-9]|6[0-689]|4[0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
+    '812' => '(?:(?:8(?:6(?:8[0134679]|3\d|0[1-9]|4[0-35-8]|7[025-8]|5[0-79]|1[0-8]|2[0-24-9]|6[0-25689])|5(?:[1-3578]\d|0[1-9]|6[0-689]|4[0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
     '813' => '(?:8(?:5(?:29|33|55|77|1[39]|0[13]|8[58])|6(?:09|2[36]|8[01])))',
     '814' => '(?:(?:8(?:5(?:65|77|0[135]|8[58]|1[0-2]|2[0245]|5[03-6])|6(?:02|51)|798)|01(?:80|9[238])))',
     '815' => '(?:8(?:5(?:33|88|4[06]|0[13]|2[09]|5[05]|1[01])|6(?:[68]6|01)))',
@@ -935,7 +935,7 @@ our %ZIP_TABLE = (
     '976' => '(?:85(?:01|10))',
     '979' => '(?:(?:0(?:19[25-8]|69[56])|2(?:39[2-4]|195|792)|1(?:[135]92|495)))',
     '980' => '(?:(?:8(?:4(?:7[78]|4[1-35-8]|8[014-8]|0[1-36-8]|2[0-369]|1[0145]|3[013569]|5[02-468]|6[016])|5(?:[15][015]|3[134]|7\d|4[346]|2[01569]|0[158]|6[0156]|8[013578])|6(?:40|86|5[0-26]|6[018]|0[1258]|3[1-36-9]|2[12]|7[017])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
-    '981' => '(?:(?:3(?:2(?:8[0178]|9[235-8])|6(?:8[0-24-68]|9[278])|1(?:9[2-5]|8[0589])|49[4-7]|[35]92)|85(?:10|33|85|6[03]|5[0-26-8]|0[25]|7[07]|2[235]|4[035])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|0394|2192))',
+    '981' => '(?:(?:3(?:2(?:8[0178]|9[235-8])|6(?:8[0-24-68]|9[278])|1(?:9[2-5]|8[0589])|49[4-7]|[35]92)|85(?:10|33|85|2[23]|6[03]|5[0-26-8]|0[25]|7[07]|4[035])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|0394|2192))',
     '982' => '(?:8(?:5(?:31|44|66|77|2[13]|8[58]|5[15]|1[01]|0[125])|601|798))',
     '983' => '(?:8(?:5(?:70|85|6[0257]|0[1247]|3[367]|4[35]|2[023]|1[1-37]|5[1256])|6(?:01|22|39)|477))',
     '984' => '(?:8(?:5(?:0[135]|7[057]|2[25]|6[0178]|8[0458]|3[0389]|1[0-2689]|5[0-3578]|4[035])|6(?:42|54|7[056]|0[13]|8[068]|6[689])))',
